@@ -4,7 +4,7 @@ register(id='craftingworld-v0',
          entry_point='gym_craftingworld.envs:CraftingWorldEnv',
          )
 
-register(id='craftingworld-trees-axes-hammers',
+register(id='craftingworld-v2',
          entry_point='gym_craftingworld.envs:CraftingWorldEnv',
          kwargs={'size': (5,5), 'object_ratios': (0, 1, 1, 0, 1, 0, 0, 0)}
          )
\ No newline at end of file
